(function () {
  "use strict";

  const defaultDuration = 250

  function enterDuration(duration) {
    if (duration) {
      if (typeof duration === 'object') {
        return duration.enter
      } else {
        return duration
      }
    } else {
      return defaultDuration
    }
  }

  function leaveDuration(duration) {
    if (duration) {
      if (typeof duration === 'object') {
        return duration.leave
      } else {
        return duration
      }
    } else {
      return defaultDuration
    }
  }

  function buildExpandTransition() {

    const expandTransitionComponent = {
      functional: true,
      props: ["duration"],
      render: (createElement, context) => {
        let data = {
          props: {
            name: "expand",
            css: false
          },
          on: {
            beforeEnter(el) {
              el.setAttribute("tempHeight", el.offsetHeight)
              el.style.height = 0
              el.style.opacity = 0
            },

            enter(el, done) {
              let height = parseInt(el.getAttribute("tempHeight"))
              el.removeAttribute("tempHeight")
              $(el).animate({height: height, opacity: 1}, enterDuration(context.props.duration), () => {
                el.removeAttribute("style")
                done
              })
            },

            leave(el, done) {
              $(el).animate({height: 0, opacity: 0}, leaveDuration(context.props.duration), () => {
                el.remove()
                done
              })
            }
          },

        }
        return createElement('transition', data, context.children)
      }
    }
    return expandTransitionComponent
  }

  if (typeof exports == "object") {
    module.exports = buildExpandTransition()
  } else if (window && window.Vue) {
    var expandTransition = buildExpandTransition()
    Vue.component('expand-transition', expandTransition)
  }
})();